@@ -90,6 +90,7 @@ from .usecases.theft_detection import TheftDetectionConfig
 from .usecases.traffic_sign_monitoring import TrafficSignMonitoringConfig
 from .usecases.crop_weed_detection import CropWeedDetectionConfig
 from .usecases.child_monitoring import ChildMonitoringConfig
+from .usecases.gender_detection import GenderDetectionConfig
 
 # Use case implementations
 from .usecases import (
@@ -122,6 +123,7 @@ from .usecases import (
     TrafficSignMonitoringUseCase,
     CropWeedDetectionUseCase,
     ChildMonitoringUseCase,
+    GenderDetectionUseCase
 )
 
 # Register use cases automatically
@@ -155,6 +157,7 @@ _emergency_vehicle_detection = EmergencyVehicleUseCase()
 _solar_panel = SolarPanelUseCase()
 _crop_weed_detection = CropWeedDetectionUseCase()
 _child_monitoring = ChildMonitoringUseCase()
+_gender_detection = GenderDetectionUseCase()
 
 registry.register_use_case(_people_counting.category, _people_counting.name, PeopleCountingUseCase)
 registry.register_use_case(_customer_service.category, _customer_service.name, CustomerServiceUseCase)
@@ -179,7 +182,7 @@ registry.register_use_case(_banana_defect_detection.category, _banana_defect_det
 registry.register_use_case(_chicken_pose_detection.category, _chicken_pose_detection.name, ChickenPoseDetectionUseCase)
 registry.register_use_case(_theft_detection.category, _theft_detection.name, TheftDetectionUseCase)
 registry.register_use_case(_traffic_sign_monitoring.category, _traffic_sign_monitoring.name, TrafficSignMonitoringUseCase)
-
+registry.register_use_case(_gender_detection.category, _gender_detection.name, GenderDetectionUseCase)
 
 registry.register_use_case(_car_damage.category, _car_damage.name, CarDamageDetectionUseCase)
 registry.register_use_case(_distracted_driver.category, _distracted_driver.name, DistractedDriverUseCase)
@@ -189,6 +192,7 @@ registry.register_use_case(_solar_panel.category, _solar_panel.name, SolarPanelU
 registry.register_use_case(_crop_weed_detection.category, _crop_weed_detection.name, CropWeedDetectionUseCase)
 registry.register_use_case(_child_monitoring.category, _child_monitoring.name, ChildMonitoringUseCase)
 
+
 # Utility functions - organized by category
 from .utils import (  # noqa: E402
     # Geometry utilities
@@ -242,7 +246,8 @@ from .utils import (  # noqa: E402
     validate_zone_polygon,
     get_use_case_examples,
     create_retail_store_zones,
-    create_office_zones
+    create_office_zones,
+
 )
 
 # Convenience functions for backward compatibility and simple usage
@@ -348,6 +353,7 @@ __all__ = [
     'TrafficSignMonitoringConfig',
     'CropWeedDetectionConfig',
     'ChildMonitoringConfig',
+    'GenderDetectionConfig',
 
     # Use case classes
     'PeopleCountingUseCase',
@@ -380,6 +386,7 @@ __all__ = [
 
     'CropWeedDetectionUseCase',
     'ChildMonitoringUseCase',
+    'GenderDetectionUseCase',
     
     # Base classes for extension
     'BaseProcessor',
