@@ -34,6 +34,7 @@ from ..usecases.theft_detection import TheftDetectionUseCase,TheftDetectionConfi
 from ..usecases.traffic_sign_monitoring import TrafficSignMonitoringConfig, TrafficSignMonitoringUseCase
 from ..usecases.crop_weed_detection import CropWeedDetectionUseCase, CropWeedDetectionConfig
 from ..usecases.child_monitoring import ChildMonitoringUseCase, ChildMonitoringConfig
+from ..usecases.gender_detection import GenderDetectionConfig, GenderDetectionUseCase
 
 __all__ = [
     'PeopleCountingUseCase',
@@ -65,6 +66,12 @@ __all__ = [
     'TrafficSignMonitoringUseCase',
     'CropWeedDetectionUseCase',
     'ChildMonitoringUseCase',
+    'GenderDetectionUseCase',
+
+
+
+
+
     'PeopleCountingConfig',
     'PotholeConfig',
     'BananaMonitoringConfig',
@@ -93,4 +100,5 @@ __all__ = [
     'TrafficSignMonitoringConfig',
     'CropWeedDetectionConfig',
     'ChildMonitoringConfig',
+    'GenderDetectionConfig'
 ]
