@@ -407,7 +407,7 @@ class ConfigManager:
             "chicken_pose_detection" : None,
             "traffic_sign_monitoring" : None,
             "theft_detection" : None,
-
+            "gender_detection": None,
             "solar_panel": None,
             "crop_weed_detection": None,
             "emergency_vehicle_detection": None,
@@ -603,6 +603,14 @@ class ConfigManager:
             return ChildMonitoringConfig
         except ImportError:
             return None
+        
+    def gender_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.gender_detection import GenderDetectionConfig
+            return GenderDetectionConfig
+        except ImportError:
+            return None
 
     def create_config(self, usecase: str, category: Optional[str] = None, **kwargs) -> BaseConfig:
         """
@@ -1106,6 +1114,22 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+        
+        elif usecase == "gender_detection":
+            # Import here to avoid circular import 
+            from ..usecases.gender_detection import GenderDetectionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+            
+            config = GenderDetectionConfig(
+                category=category or "general",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
             
         else:
             raise ConfigValidationError(f"Unknown use case: {usecase}")
@@ -1340,6 +1364,11 @@ class ConfigManager:
             from ..usecases.child_monitoring import ChildMonitoringConfig
             default_config = ChildMonitoringConfig()
             return default_config.to_dict()
+        elif usecase == "gender_detection":
+            # Import here to avoid circular import
+            from ..usecases.gender_detection import GenderDetectionConfig
+            default_config = GenderDetectionConfig()
+            return default_config.to_dict()
 
         elif usecase not in self._config_classes:
             raise ConfigValidationError(f"Unsupported use case: {usecase}")
