@@ -58,7 +58,8 @@ from .usecases import (
     EmergencyVehicleUseCase,
     SolarPanelUseCase,
     CropWeedDetectionUseCase,
-    ChildMonitoringUseCase
+    ChildMonitoringUseCase,
+    GenderDetectionUseCase
 
 
 )
@@ -151,6 +152,7 @@ class PostProcessor:
         registry.register_use_case("agriculture", "chicken_pose_detection", ChickenPoseDetectionUseCase)
         registry.register_use_case("agriculture", "crop_weed_detection", CropWeedDetectionUseCase)
         registry.register_use_case("security", "child_monitoring", ChildMonitoringUseCase)
+        registry.register_use_case("general", "gender_detection", GenderDetectionUseCase)
         
         logger.debug("Registered use cases with registry")
     
@@ -263,6 +265,8 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, PriceTagUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, GenderDetectionUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
             else:
                 result = use_case.process(data, parsed_config, context, stream_info)
             
