@@ -36,7 +36,7 @@ from .traffic_sign_monitoring import TrafficSignMonitoringConfig, TrafficSignMon
 from .theft_detection import TheftDetectionConfig , TheftDetectionUseCase
 from .crop_weed_detection import CropWeedDetectionConfig, CropWeedDetectionUseCase
 from .child_monitoring import ChildMonitoringUseCase, ChildMonitoringConfig
-
+from .gender_detection import GenderDetectionUseCase, GenderDetectionConfig
 
 __all__ = [
     'PeopleCountingUseCase',
@@ -68,6 +68,7 @@ __all__ = [
     'ChickenPoseDetectionUseCase',
     'CropWeedDetectionUseCase',
     'ChildMonitoringUseCase',
+    'GenderDetectionUseCase',
     'PeopleCountingConfig',
     'ParkingSpaceConfig',
     'CustomerServiceConfig',
@@ -96,5 +97,6 @@ __all__ = [
     'SolarPanelConfig'
     'SolarPanelConfig',
     'CropWeedDetectionConfig',
-    'ChildMonitoringConfig'
+    'ChildMonitoringConfig',
+    'GenderDetectionConfig'
 ]
\ No newline at end of file
