@@ -24,20 +24,17 @@ class WeldDefectConfig(BaseConfig):
     smoothing_confidence_range_factor: float = 0.5
     confidence_threshold: float = 0.6
     defect_categories: List[str] = field(
-        default_factory=lambda: ['Bad Welding', 'Crack', 'Porosity', 'Spatters', 'Good Welding', 'Reinforcement']
+        default_factory=lambda: ['Bad Weld','Good Weld','Defect']
     )
     target_defect_categories: List[str] = field(
-        default_factory=lambda: ['Bad Welding', 'Crack', 'Porosity', 'Spatters']
+        default_factory=lambda: ['Bad Weld','Good Weld','Defect']
     )
     alert_config: Optional[AlertConfig] = None
     index_to_category: Optional[Dict[int, str]] = field(
         default_factory=lambda: {
-            0: "Bad Welding",
-            1: "Crack",
-            2: "Good Welding",
-            3: "Porosity",
-            4: "Reinforcement",
-            5: "Spatters"
+            0: "Bad Weld",
+            1: "Good Weld",
+            2: "Defect",
         }
     )
 
@@ -47,7 +44,7 @@ class WeldDefectUseCase(BaseProcessor):
     def __init__(self):
         super().__init__("weld_defect_detection")
         self.category = "weld"
-        self.defect_categories = ['Bad Welding', 'Crack', 'Porosity', 'Spatters', 'Good Welding', 'Reinforcement']
+        self.defect_categories = ['Bad Weld','Good Weld','Defect']
         self.smoothing_tracker = None
         self.tracker = None
         self._total_frame_counter = 0
@@ -413,12 +410,9 @@ class WeldDefectUseCase(BaseProcessor):
         }
 
     CATEGORY_DISPLAY = {
-        "Bad Welding": "Bad Welding",
-        "Crack": "Crack",
-        "Porosity": "Porosity",
-        "Spatters": "Spatters",
-        "Good Welding": "Good Welding",
-        "Reinforcement": "Reinforcement"
+        "Bad Weld": "Bad Weld",
+        "Good Weld": "Good Weld",
+        "Defect": "Defect",
     }
 
     def _generate_insights(self, summary: dict, config: WeldDefectConfig) -> List[str]:
